#
# spec file for package python-affine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-affine
Version:        2.4.0
Release:        2.4
Summary:        Affine transformation matrices
License:        BSD-3-Clause
URL:            https://github.com/sgillies/affine
Source:         https://files.pythonhosted.org/packages/source/a/affine/affine-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 3.0}
# /SECTION
%python_subpackages

%description
Matrices describing affine transformation of the plane.

%prep
%setup -q -n affine-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS.txt CHANGES.txt README.rst
%license LICENSE.txt
%{python_sitelib}/affine
%{python_sitelib}/affine-%{version}.dist-info

%changelog
* Wed Aug 21 2024 Dirk Müller <dmueller@suse.com>
- use modern python for sle15
* Mon Jan 29 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.4.0:
  * Elimination of Python 2/3 compatibility code in __gt__ (#94).
  * Addition of optional keyword arguments for __new__, solving an issue with
    Dask (#92).
  * Addition of some type hints for float arguments and return types (#87).
  * Python version support is now 3.7-3.11 (#82).
  * Faster __new__ and from_gdal methods (#78).
- Switch to pyproject macros.
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Return NotImplemented for both ValueError and TypeError in __mul__ to
    support fallback to __rmul__ in more cases (gh-71).
* Sun Jan 16 2022 Ben Greiner <code@bnavigator.de>
- Don't check code coverage
* Wed Jan 13 2021 pgajdos@suse.com
- use %%pytest macro
* Tue Feb 11 2020 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 2.3.0
  + Right multiplication like vector * matrix is deprecated and will
    raise AffineError in version 3.0.0.
  + Change signature of Affine constructor to help users of PyCharm
  + The Affine class docstring has been improved.
- cleaning spec
* Wed Mar  6 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.2.2
  * Affine.itransform computed the wrong results for arrays with rotation or
    shear (#40). This is fixed (#41).
- Update to 2.2.1
  * Docstring improvements (#37).
- Update to 2.2.0
  * Addition of permutation matrix (#35).
- Update to 2.1.0
  * Addition of new ``eccentricity`` and ``rotation_angle`` properties (#28).
- Update to 2.0.0
  * Bug fix: restore ``Affine __rmul__`` even though it permits dubious
    vector * matrix expressions (#27).
  * Breaking change: precision used in properties like ``is_conformal`` is no
    longer a global module attribute, but an Affine class or instance attribute
    (#19, #20).
  * Breaking change: ``is_degenerate`` property is now exact and not subject to
    a level of precision (#23).
  * Breaking change: we have reversed our sense of rotation, a positive angle
    now rotates a point counter-clockwise about the pivot point (#25).
  * Bug fix: a bug in matrix-vector multiplication had been reversing the
    direction of rotation and is now fixed (#25).
- Update to 1.3.0
  * is_degenerate predicate is precise, not approximate (#22)
- Implement single-spec version
* Tue Jun  9 2015 Angelos Tzotsos <tzotsos@opensuse.org>
- initial packaging (1.2.0)
